Functions
- call_
ref - Returns the name of the function call that takes an argument by reference.
- call_
val - Returns the name of the function call that takes an argument by value.
- default_
ref_ type - Returns the default name for a ref type.
- emit_
ref - Returns the name of the event emitter that takes an argument by reference.
- emit_
val - Returns the name of the event emitter that takes an argument by value.
- enum_
ref_ type_ ctor - Returns the name of the constructor function in a ref type for an enum’s variant.
- event_
args - Returns the name for an inline struct or enum used as an event’s argument.
- event_
variant - Returns the name for an event’s enum variant.
- function_
args - Returns the name for an inline struct or enum used as a functions’s
args. - function_
err - Returns the name for an inline struct or enum used as a functions’s
err. - function_
ok - Returns the name for an inline struct or enum used as a functions’s
ok. - function_
variant - Returns the name for a functions’s enum variant.
- register_
introspection - service_
call - Returns the name of a service’s call type.
- service_
call_ handler - Returns the name of a service’s call handler trait.
- service_
event - Returns the name of a service’s event type.
- service_
event_ handler - Returns the name of a service’s event handler trait.
- service_
introspection - Returns the name of a service’s introspection type.
- service_
local_ call_ handler - Returns the name of a service’s local call handler trait.
- service_
local_ event_ handler - Returns the name of a service’s local event handler trait.
- service_
proxy - Returns the name of a service’s proxy type.
- subscribe
- Returns the name of event’s subscribe function.
- unsubscribe
- Returns the name of event’s unsubscribe function.